translate.misc.sparse

Package translate :: Package misc :: Module sparse |
[hide private]
[frames] | no frames]

# Module sparse

source code

simple parser / string tokenizer rather than returning a list of token types etc, we simple return a list of tokens... each tokenizing function takes a string as input and returns a list of tokens

Classes | [hide private]
| ParserError Intelligent parser error
| SimpleParser this is a simple parser

Functions | [hide private]
stringeval(text) takes away repeated quotes (escapes) and returns the string represented by the text | source code
stringquote(text) escapes quotes as neccessary and returns a string representing the text | source code

Variables | [hide private]
| __package__ = `None` hash(x)